@@ -1,6 +1,6 @@
 /* itf.c - IP interface registry */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -94,7 +94,7 @@ void itf_down(int number)
     diag(COMPONENT,DIAG_DEBUG,"ITF DOWN %d",number);
     itf = lookup_itf(number);
     if (!itf) {
-	diag(COMPONENT,DIAG_ERROR,"no such interface");
+	diag(COMPONENT,DIAG_ERROR,"no such interface (%d)",number);
 	return;
     }
     itf_bring_down(itf);
@@ -111,7 +111,7 @@ void itf_change(int number)
     diag(COMPONENT,DIAG_DEBUG,"ITF CHANGE %d",number);
     itf = lookup_itf(number);
     if (!itf) {
-	diag(COMPONENT,DIAG_ERROR,"no such interface");
+	diag(COMPONENT,DIAG_ERROR,"no such interface (%d)",number);
 	return;
     }
     if (ip_itf_info(number,&local_ip,&netmask,&mtu) < 0) {
