@@ -248,6 +248,7 @@ int open_ilmi(int itf,const char *qos_spec)
     if((fd = socket(PF_ATMPVC, SOCK_DGRAM, 0)) < 0)
       diag(COMPONENT, DIAG_FATAL, "socket: %s", strerror(errno));
 
+    atm_itf = itf;
     memset(&qos, 0, sizeof(qos));
     qos.rxtp.max_sdu = MAX_ILMI_MSG;
     qos.txtp.max_sdu = MAX_ILMI_MSG;
@@ -269,3 +270,22 @@ int open_ilmi(int itf,const char *qos_spec)
 
     return fd;
 }
+
+
+int get_ci_range(struct atm_cirange *ci)
+{
+    struct atmif_sioc req;
+    int fd,error;
+
+    fd = socket(PF_ATMPVC,SOCK_DGRAM,0);
+    if (fd < 0) diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
+    req.number = atm_itf;
+    req.length = sizeof(*ci);
+    req.arg = ci;
+    error = ioctl(fd,ATM_GETCIRANGE,&req);
+    (void) close(fd);
+    if (error < 0) {
+	diag(COMPONENT,DIAG_ERROR,"ioctl ATM_GETCIRANGE: %s",strerror(errno));
+	return error;
+    }
+}
