@@ -13,13 +13,6 @@
 #endif
 
 
-#ifdef UNI40
-#include "q40.out.h"
-#else
-#include "q.out.h"
-#endif
-
-
 /*
  * Severity codes used by the run-time library. Surprisingly, they happen to
  * have the same numerical values as their corresponding atmsigd counterparts.
@@ -68,7 +61,7 @@ typedef struct {
     unsigned long *group_present;
     int *length;
     int *field_map;
-    int *group_map;
+    int *group_map; /* @@@ useless overhead until we allow nested structures */
     void *buffer;
     int buf_size;
     int error;
@@ -164,7 +157,7 @@ int q_length(const Q_DSC *dsc,int field);
 
 /*
  * Enables all instances which are controlled by the specified group.
- * It is an error to use a groups that controls no instances.
+ * It is an error to use a group that controls no instances.
  */
 
 void q_instance(Q_DSC *dsc,int group);
