@@ -1,6 +1,6 @@
 /* proto.c - Common protocol functions and structures */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdarg.h>
@@ -355,11 +355,22 @@ void enter_vpci(SIG_ENTITY *sig,int vpci,int itf)
     entry = alloc_t(VPCI);
     entry->vpci = vpci;
     entry->itf = itf;
+    entry->local_addr[0].state = ls_unused;
     entry->next = sig->vpcis;
     sig->vpcis = entry;
 }
 
 
+void set_vpi_0(SIG_ENTITY *sig)
+{
+    VPCI *vpci;
+
+    for (vpci = sig->vpcis; vpci; vpci = vpci->next)
+	if (!vpci->vpci) return;
+    enter_vpci(sig,0,sig->signaling_pvc.sap_addr.itf);
+}
+
+
 int get_itf(SIG_ENTITY *sig,int *vpci)
 {
     VPCI *best,*walk;
@@ -376,10 +387,48 @@ int get_itf(SIG_ENTITY *sig,int *vpci)
 
 void init_addr(SIG_ENTITY *sig)
 {
-    VPCI *walk;
+    VPCI *vpci;
 
-    itf_load(sig->signaling_pvc.sap_addr.itf);
-    for (walk = sig->vpcis; walk; walk = walk->next) itf_load(walk->itf);
+    for (vpci = sig->vpcis; vpci; vpci = vpci->next) sync_addr(vpci);
+}
+
+
+void itf_reload(int itf)
+{
+    SIG_ENTITY *sig;
+    VPCI *vpci;
+
+    for (sig = entities; sig; sig = sig->next)
+	for (vpci = sig->vpcis; vpci; vpci = vpci->next)
+	    if (vpci->itf == itf) sync_addr(vpci);
+}
+
+
+static struct sockaddr_atmsvc *do_get_local(SIG_ENTITY *sig)
+{
+    VPCI *vpci;
+    LOCAL_ADDR *local;
+
+    for (vpci = sig->vpcis; vpci; vpci = vpci->next)
+	for (local = vpci->local_addr; local->state != ls_unused; local++)
+	    if (local->state == ls_same && atmsvc_addr_in_use(local->addr))
+		return &local->addr;
+    return NULL;
+
+}
+
+
+struct sockaddr_atmsvc *get_local(SIG_ENTITY *sig)
+{
+    SIG_ENTITY *entity;
+    struct sockaddr_atmsvc *local;
+
+    if (sig) return do_get_local(sig);
+    for (entity = entities; entity; entity = entity->next) {
+	local = do_get_local(entity);
+	if (local) return local;
+    }
+    return NULL;
 }
 
 
@@ -442,25 +491,42 @@ SIG_ENTITY *route_remote(struct sockaddr_atmsvc *addr)
 }
 
 
-SIG_ENTITY *get_sig_entity(int itf)
+SIG_ENTITY *route_local(struct sockaddr_atmsvc *addr)
 {
     SIG_ENTITY *sig;
+    VPCI *vpci;
+    LOCAL_ADDR *walk;
 
+    /*
+     * @@@ This is quite close to the truth but still not entirely correct:
+     * the actual result should be the VPCI to use. While this is irrelevant
+     * when the connection identifier is assigned by the peer, the VPI
+     * selection should be based on the VPCI we find here if it's atmsigd who
+     * assigns the connection identifier. The bottom line is that VPI > 0 plus
+     * connection identifier assignment by atmsigd doesn't work yet.
+     */
     for (sig = entities; sig; sig = sig->next)
-	if (sig->signaling_pvc.sap_addr.itf == itf) return sig;
-    /* should also check for vpcis @@@ */
+	for (vpci = sig->vpcis; vpci; vpci = vpci->next)
+	    for (walk = vpci->local_addr; walk->state != ls_unused; walk++)
+		if (walk->state == ls_same && atm_equal((struct sockaddr *)
+		  &walk->addr,(struct sockaddr *) addr,(ATM_ESA_LEN-1)*8,
+		  AXE_WILDCARD))
+		    return sig;
     return NULL;
 }
 
 
-SIG_ENTITY *route_local(struct sockaddr_atmsvc *addr)
+int get_max_rate(SIG_ENTITY *sig)
 {
-    LOCAL_ADDR *walk;
+    VPCI *vpci;
+    int max;
 
-    for (walk = local_addr; walk->state != ls_unused; walk++)
-	if (walk->state == ls_same && atm_equal((struct sockaddr *) &walk->addr,
-	  (struct sockaddr *) addr,(ATM_ESA_LEN-1)*8,AXE_WILDCARD))
-	    break;
-    if (walk->state == ls_unused) return NULL;
-    return get_sig_entity(walk->itf);
+    max = 0;
+    for (vpci = sig->vpcis; vpci; vpci = vpci->next) {
+	int curr;
+
+	curr = get_link_rate(vpci->itf);
+	if (curr > max) max = curr;
+    }
+    return max;
 }
