@@ -42,9 +42,18 @@ typedef enum { ps_null,ps_add_init,ps_add_recv = 6,ps_drop_init = 11,
 
 typedef enum { sm_unknown,sm_user,sm_net,sm_switch } SIGNALING_MODE;
 
+typedef struct {
+    enum { ls_unused,ls_added,ls_removed,ls_same } state;
+    struct sockaddr_atmsvc addr;
+} LOCAL_ADDR;
+
+#define MAX_LOCAL_ADDRS 32
+
 typedef struct _vpci {
     int vpci;
     int itf;
+//    struct _sig_entity *sig; /* back pointer */
+    LOCAL_ADDR local_addr[MAX_LOCAL_ADDRS+1];
     struct _vpci *next;
 } VPCI;
 
@@ -54,6 +63,7 @@ typedef struct _sig_entity {
     SIGNALING_MODE mode;
     int sig_pcr; /* @@@ remove soon */
     const char *sig_qos;
+    int max_rate;
     struct sockaddr_atmpvc signaling_pvc;
     SAAL_DSC saal;
     VPCI *vpcis;
@@ -124,7 +134,7 @@ extern int stop;
 void poll_signals(void);
 
 void from_kernel(struct atmsvc_msg *msg,int size);
-void itf_load(int itf);
+void sync_addr(VPCI *vpci);
 
 void to_uni(SIG_ENTITY *sig,void *msg,int size);
 void send_kernel(unsigned long vcc,unsigned long listen_vcc,
@@ -160,13 +170,16 @@ void send_close(SOCKET *sock);
 int get_vci(int itf);
 
 void enter_vpci(SIG_ENTITY *sig,int vpci,int itf);
+void set_vpi_0(SIG_ENTITY *sig);
 int get_itf(SIG_ENTITY *sig,int *vpci);
 void init_addr(SIG_ENTITY *sig);
+void itf_reload(int itf);
+struct sockaddr_atmsvc *get_local(SIG_ENTITY *sig);
 
 void add_route(SIG_ENTITY *sig,struct sockaddr_atmsvc *addr,int len);
 SIG_ENTITY *route_remote(struct sockaddr_atmsvc *addr);
 SIG_ENTITY *route_local(struct sockaddr_atmsvc *addr);
 
-SIG_ENTITY *get_sig_entity(int itf);
+int get_max_rate(SIG_ENTITY *sig);
 
 #endif
